mod cli;
mod lm_sensors;
mod nvidia_smi;
mod sensor_names;
use cli::Arguments;
use lm_sensors::{sensors_data, Sensor};
use nvidia_smi::temperature;
use structopt::StructOpt;

fn main() {
    let opts = Arguments::from_args();
    match opts {
        Arguments::Cpu => print_cpu_temp(),
        Arguments::Gpu => print_gpu_temp(),
        Arguments::Disk => print_disk_temp(),
        Arguments::Debug => debug(),
    }
}

fn print_cpu_temp() {
    let sensors_data = sensors_data();
    if let Ok(sensors) = sensors_data {
        print_chip_temp(sensors.cpu_chip());
    }
}

fn print_disk_temp() {
    let sensors_data = sensors_data();
    if let Ok(sensors) = sensors_data {
        print_chip_temp(sensors.disk_chip());
    }
}

fn print_chip_temp(chip: Option<&Sensor>) {
    if let Some(chip) = chip {
        if let Some(temp) = chip.temp() {
            println!("{}", temp);
        }
    }
}

fn print_gpu_temp() {
    let gpu_temp_data = temperature();
    if let Ok(temp) = gpu_temp_data {
        println!("{}", temp)
    }
}

fn debug() {
    let sensors_data = sensors_data();
    println!("lm-sensors: {:?}", sensors_data);

    let nvidia_smi_temp = temperature();
    println!("nvidia-smi: {:?}", nvidia_smi_temp);
}
